.. python-mbedtls documentation master file, created by
   sphinx-quickstart on Tue Dec 15 12:11:16 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

API documentation
=================

.. toctree::
   :maxdepth: 2

   apisecrets
   apitls
   apix509
   apipk
   apicipher
   apimd
   apimpi


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

